@@ -6,17 +6,19 @@
 #' @param labels labels params
 #' @param quantities quantities params
 #' @param number current diagram number
-#' @param centers data.frame of data for labels and quantities
+#' @param merged_sets sets that are the same and have been merged
 #'
 #' @return A [grid::gList()] is returned.
 #' @keywords internal
-setup_grobs <- function(x,
-                        fills,
-                        edges,
-                        labels,
-                        quantities,
-                        number,
-                        merged_sets) {
+setup_grobs <- function(
+  x,
+  fills,
+  edges,
+  labels,
+  quantities,
+  number,
+  merged_sets
+) {
   data_edges <- x$edges
   data_fills <- x$fills
   data_tags <- x$centers
@@ -43,12 +45,14 @@ setup_grobs <- function(x,
     if (is.null(data_edges$x)) {
       edges_grob <- grid::nullGrob()
     } else {
-      edges_grob <- grid::polylineGrob(data_edges$x,
-                                       data_edges$y,
-                                       id.lengths = data_edges$id.lengths,
-                                       default.units = "native",
-                                       name = "edges.grob",
-                                       gp = edges$gp[which(!empty_sets & !merged_sets)])
+      edges_grob <- grid::polylineGrob(
+        data_edges$x,
+        data_edges$y,
+        id.lengths = data_edges$id.lengths,
+        default.units = "native",
+        name = "edges.grob",
+        gp = edges$gp[which(!empty_sets & !merged_sets)]
+      )
     }
   }
 
@@ -75,8 +79,11 @@ setup_grobs <- function(x,
           idx <- id[i, ]
           n_idx <- sum(idx)
           sub_id <- rowSums(id[, idx, drop = FALSE]) == n_idx
-          next_num <- min(rowSums(id[sub_id & rowSums(id) > n_idx & !empty, ,
-                                     drop = FALSE]))
+          next_num <- min(rowSums(id[
+            sub_id & rowSums(id) > n_idx & !empty,
+            ,
+            drop = FALSE
+          ]))
           next_level <- rowSums(id) == next_num & sub_id
           if (any(next_level)) {
             fill_id[next_level] <- fill_id[i]
@@ -87,7 +94,7 @@ setup_grobs <- function(x,
       for (i in seq_len(n_id)) {
         if (is.null(data_fills[[i]])) {
           fills_grob[[i]] <- grid::nullGrob(name = paste0("fills.grob.", i))
-        } else
+        } else {
           fills_grob[[i]] <- grid::pathGrob(
             data_fills[[i]]$x,
             data_fills[[i]]$y,
@@ -96,6 +103,7 @@ setup_grobs <- function(x,
             name = paste0("fills.grob.", i),
             gp = fills$gp[which(!empty_subsets)][fill_id[i]]
           )
+        }
       }
       fills_grob <- do.call(grid::gList, fills_grob)
     }
@@ -108,21 +116,27 @@ setup_grobs <- function(x,
     tag_grobs <- gList()
 
     for (i in seq_len(NROW(data_tags))) {
-      tag_grobs[[i]] <- setup_tag(data_tags[i, ],
-                                  labels,
-                                  quantities,
-                                  number = i)
+      tag_grobs[[i]] <- setup_tag(
+        data_tags[i, ],
+        labels,
+        quantities,
+        number = i
+      )
     }
 
-    tags_gtree <- gTree(xlim = xlim,
-                        ylim = ylim,
-                        children = tag_grobs,
-                        name = paste("tags"),
-                        cl = "EulerTags")
+    tags_gtree <- gTree(
+      xlim = xlim,
+      ylim = ylim,
+      children = tag_grobs,
+      name = paste("tags"),
+      cl = "EulerTags"
+    )
   }
 
-  grid::grobTree(if (do_fills) fills_grob,
-                 if (do_edges) edges_grob,
-                 if (do_tags) tags_gtree,
-                 name = paste0("diagram.grob.", number))
+  grid::grobTree(
+    if (do_fills) fills_grob,
+    if (do_edges) edges_grob,
+    if (do_tags) tags_gtree,
+    name = paste0("diagram.grob.", number)
+  )
 }
