@@ -1,10 +1,10 @@
-#ifndef eulerr_transformations_h_
-#define eulerr_transformations_h_
+#pragma once
 
 #include <RcppArmadillo.h>
 
 // Return the adjoint (adjugate) of a 3-by-3 matrix
-inline arma::mat adjoint(const arma::mat& m)
+inline arma::mat
+adjoint(const arma::mat& m)
 {
   arma::mat::fixed<3, 3> out;
 
@@ -15,42 +15,42 @@ inline arma::mat adjoint(const arma::mat& m)
   auto e = m(2, 1);
   auto f = m(2, 2);
 
-  out(0, 0) = c*f - e*e;
-  out(1, 0) = d*e - b*f;
-  out(1, 1) = a*f - d*d;
-  out(2, 0) = b*e - c*d;
-  out(2, 1) = b*d - a*e;
-  out(2, 2) = a*c - b*b;
+  out(0, 0) = c * f - e * e;
+  out(1, 0) = d * e - b * f;
+  out(1, 1) = a * f - d * d;
+  out(2, 0) = b * e - c * d;
+  out(2, 1) = b * d - a * e;
+  out(2, 2) = a * c - b * b;
 
   return arma::symmatl(out);
 }
 
 // Skew-symmetric matrix for complex matrices
-inline arma::cx_mat skewsymmat(const arma::cx_vec& v)
+inline arma::cx_mat
+skewsymmat(const arma::cx_vec& v)
 {
   arma::cx_mat::fixed<3, 3> out;
   out.diag().zeros();
-  out(0, 1) =  v(2);
+  out(0, 1) = v(2);
   out(0, 2) = -v(1);
   out(1, 0) = -v(2);
-  out(1, 2) =  v(0);
-  out(2, 0) =  v(1);
+  out(1, 2) = v(0);
+  out(2, 0) = v(1);
   out(2, 1) = -v(0);
   return out;
 }
 
 // Skew-symmetric matrix
-inline arma::mat skewsymmat(const arma::vec& v)
+inline arma::mat
+skewsymmat(const arma::vec& v)
 {
   arma::mat::fixed<3, 3> out;
   out.diag().zeros();
-  out(0, 1) =  v(2);
+  out(0, 1) = v(2);
   out(0, 2) = -v(1);
   out(1, 0) = -v(2);
-  out(1, 2) =  v(0);
-  out(2, 0) =  v(1);
+  out(1, 2) = v(0);
+  out(2, 0) = v(1);
   out(2, 1) = -v(0);
   return out;
 }
-
-#endif // eulerr_transformations_h_
